Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SetupTestCerts ¶
SetupTestCerts populates the given test LXD directory with server certificates.
Since generating certificates is CPU intensive, they will be simply symlink'ed from the test/deps/ directory.
FIXME: this function is exported because some tests use it
directly. Eventually we should rework those tests to use NewTestOS instead.
Types ¶
type InotifyInfo ¶
type InotifyInfo struct {
Fd int
sync.RWMutex
Targets map[string]*InotifyTargetInfo
}
InotifyInfo records the inotify information associated with a given inotify instance
type InotifyTargetInfo ¶
InotifyTargetInfo records the inotify information associated with a given inotify target
type OS ¶
type OS struct {
// Directories
CacheDir string // Cache directory (e.g. /var/cache/lxd/).
LogDir string // Log directory (e.g. /var/log/lxd).
VarDir string // Data directory (e.g. /var/lib/lxd/).
// Daemon environment
Architectures []int // Cache of detected system architectures
BackingFS string // Backing filesystem of $LXD_DIR/containers
ExecPath string // Absolute path to the LXD executable
IdmapSet *idmap.IdmapSet // Information about user/group ID mapping
InotifyWatch InotifyInfo
LxcPath string // Path to the $LXD_DIR/containers directory
MockMode bool // If true some APIs will be mocked (for testing)
RunningInUserNS bool
UnprivUser string
UnprivUID int
// Apparmor features
AppArmorAdmin bool
AppArmorAvailable bool
AppArmorConfined bool
AppArmorStacked bool
AppArmorStacking bool
// Cgroup features
CGInfo cgroup.Info
// Kernel features
NetnsGetifaddrs bool
SeccompListener bool
SeccompListenerContinue bool
Shiftfs bool
UeventInjection bool
VFS3Fscaps bool
// LXC features
LXCFeatures map[string]bool
}
OS is a high-level facade for accessing all operating-system level functionality that LXD uses.
func DefaultOS ¶
func DefaultOS() *OS
DefaultOS returns a fresh uninitialized OS instance with default values.
func (*OS) GlobalDatabaseDir ¶
GlobalDatabaseDir returns the path of the global database directory.
func (*OS) GlobalDatabasePath ¶
GlobalDatabasePath returns the path of the global database SQLite file managed by dqlite.
func (*OS) LegacyGlobalDatabasePath ¶
LegacyGlobalDatabasePath returns the path of legacy global database file.
func (*OS) LegacyLocalDatabasePath ¶
LegacyLocalDatabasePath returns the path of legacy local database file.
func (*OS) LocalDatabasePath ¶
LocalDatabasePath returns the path of the local database file.